Index: recipes/webrtc_ios.py |
diff --git a/recipes/ios.py b/recipes/webrtc_ios.py |
similarity index 57% |
copy from recipes/ios.py |
copy to recipes/webrtc_ios.py |
index e7ee08b6d569a4efb867feaf4b4c09d163b78437..550ad8d3fa9dd8b84c03feb808e65d3f5ebf14ae 100644 |
--- a/recipes/ios.py |
+++ b/recipes/webrtc_ios.py |
@@ -1,4 +1,4 @@ |
-# Copyright 2013 The Chromium Authors. All rights reserved. |
+# Copyright 2014 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
@@ -9,21 +9,25 @@ import recipe_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class IOS(recipe_util.Recipe): |
- """Basic Recipe alias for iOS -> Chromium.""" |
+class WebRTCIOS(recipe_util.Recipe): |
+ """Basic Recipe alias for iOS -> WebRTC.""" |
@staticmethod |
def fetch_spec(props): |
return { |
'alias': { |
- 'recipe': 'chromium', |
- 'props': ['--target_os=ios', '--target_os_only=True'], |
+ 'recipe': 'webrtc', |
+ 'props': ['--target_os=ios,mac'], |
}, |
} |
+ @staticmethod |
+ def expected_root(_props): |
+ return 'src' |
+ |
def main(argv=None): |
- return IOS().handle_args(argv) |
+ return WebRTCIOS().handle_args(argv) |
if __name__ == '__main__': |